"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createExecutionPlan = void 0;
const config_sets_1 = require("@takomo/config-sets");
const create_config_set_execution_plan_1 = require("./create-config-set-execution-plan");
const get_execution_role_arn_1 = require("./get-execution-role-arn");
const createExecutionPlan = async (props) => {
    const { ctx, targetsSelectionCriteria: { configSetType, configSetName, commandPath }, } = props;
    const callerIdentity = await ctx.credentialManager.getCallerIdentity();
    const getConfigSetsWithStage = (target, stageName) => (0, config_sets_1.getConfigSetsByType)(configSetType, target).filter((cs) => cs.stage === stageName);
    const hasConfigSetsWithStage = (target, stageName) => getConfigSetsWithStage(target, stageName).length > 0;
    const convertToExecutionTarget = (target, stageName, group) => ({
        id: target.name,
        vars: target.vars,
        configSets: getConfigSetsWithStage(target, stageName)
            .map((cs) => cs.name)
            .filter((csName) => !configSetName || csName === configSetName)
            .map((csName) => ctx.getConfigSet(csName))
            .map((cs) => ({
            name: cs.name,
            commandPaths: commandPath ? [commandPath] : cs.commandPaths,
        })),
        data: {
            ...target,
            deploymentGroup: {
                name: group.name,
                path: group.path,
            },
            executionRoleArn: (0, get_execution_role_arn_1.getExecutionRoleArn)(configSetType, callerIdentity, target),
        },
    });
    const executionGroupConverter = (group, stageName) => ({
        id: group.path,
        targets: group.targets
            .filter((target) => hasConfigSetsWithStage(target, stageName))
            .map((target) => convertToExecutionTarget(target, stageName, group))
            .filter(({ configSets }) => configSets.length > 0),
    });
    return (0, create_config_set_execution_plan_1.createConfigSetExecutionPlan)({ ...props, executionGroupConverter });
};
exports.createExecutionPlan = createExecutionPlan;
//# sourceMappingURL=config-set-execution-plan.js.map